"""Domain allowlist constants."""

from __future__ import annotations

DEFAULT_ALLOWLISTED_DOMAINS: tuple[str, ...] = (
    "github.com",
    "gitlab.com",
    "bitbucket.org",
    "stackoverflow.com",
    "npmjs.com",
    "pypi.org",
    "docs.python.org",
    "developer.mozilla.org",
    "wikipedia.org",
    "modelcontextprotocol.io",
    "anthropic.com",
    "openai.com",
)
